==> tss-react-4.8.7.tgz: package/esm/next/appDir.js <==
"use client";
import React from "react";
import createCache from "@emotion/cache";
import { useServerInsertedHTML } from "next/navigation";
import { useState } from "react";
import { CacheProvider as DefaultCacheProvider } from "@emotion/react";
export function NextAppDirEmotionCacheProvider(props) {
    const { options, CacheProvider = DefaultCacheProvider, children } = props;
    const [{ cache, flush }] = useState(() => {
        const cache = createCache(options);
        cache.compat = true;
        const prevInsert = cache.insert;
        let inserted = [];
        cache.insert = (...args) => {
            const [selector, serialized] = args;
            if (cache.inserted[serialized.name] === undefined) {
                inserted.push({
                    "name": serialized.name,
                    "isGlobal": selector === ""
                });
            }
            return prevInsert(...args);
        };
        const flush = () => {
            const prevInserted = inserted;
            inserted = [];
            return prevInserted;
        };
        return { cache, flush };
    });
    useServerInsertedHTML(() => {
        const inserted = flush();
        if (inserted.length === 0) {
            return null;
        }
        let styles = "";
        let dataEmotionAttribute = `${cache.key}`;
        let globalStyles = "";
        let globalDataEmotionAttribute = `${cache.key}-global`;
        for (const { name, isGlobal } of inserted) {
            const style = cache.inserted[name];
            if (isGlobal) {
                globalStyles += style;
                globalDataEmotionAttribute += ` ${name}`;
            }
            else {
                styles += style;
                dataEmotionAttribute += ` ${name}`;
            }
        }
        return (React.createElement(React.Fragment, null,
            globalStyles !== "" && (React.createElement("style", { key: `${cache.key}-global`, "data-emotion": globalDataEmotionAttribute, dangerouslySetInnerHTML: {
                    "__html": globalStyles
                } })),
            styles !== "" && (React.createElement("style", { key: cache.key, "data-emotion": dataEmotionAttribute, dangerouslySetInnerHTML: {
                    "__html": styles
                } }))));
    });
    return React.createElement(CacheProvider, { value: cache }, children);
}
export default NextAppDirEmotionCacheProvider;

==> tss-react-4.8.8.tgz: package/esm/next/appDir.js <==
"use client";
import React from "react";
import createCache from "@emotion/cache";
import { useServerInsertedHTML } from "next/navigation";
import { useState } from "react";
import { CacheProvider as DefaultCacheProvider } from "@emotion/react";
export function NextAppDirEmotionCacheProvider(props) {
    const { options, CacheProvider = DefaultCacheProvider, children } = props;
    const [{ cache, flush }] = useState(() => {
        const cache = createCache(options);
        cache.compat = true;
        const prevInsert = cache.insert;
        let inserted = [];
        cache.insert = (...args) => {
            const [selector, serialized] = args;
            if (cache.inserted[serialized.name] === undefined) {
                inserted.push({
                    "name": serialized.name,
                    "isGlobal": selector === ""
                });
            }
            return prevInsert(...args);
        };
        const flush = () => {
            const prevInserted = inserted;
            inserted = [];
            return prevInserted;
        };
        return { cache, flush };
    });
    useServerInsertedHTML(() => {
        const inserted = flush();
        if (inserted.length === 0) {
            return null;
        }
        let styles = "";
        let dataEmotionAttribute = cache.key;
        const global = [];
        for (const { name, isGlobal } of inserted) {
            const style = cache.inserted[name];
            if (typeof style === "boolean") {
                continue;
            }
            if (isGlobal) {
                global.push({ name, style });
            }
            else {
                styles += style;
                dataEmotionAttribute += ` ${name}`;
            }
        }
        return (React.createElement(React.Fragment, null,
            global.map(({ name, style }) => (React.createElement("style", { key: name, "data-emotion": `${cache.key}-global ${name}`, dangerouslySetInnerHTML: { "__html": style } }))),
            styles !== "" && (React.createElement("style", { "data-emotion": dataEmotionAttribute, dangerouslySetInnerHTML: { "__html": styles } }))));
    });
    return React.createElement(CacheProvider, { value: cache }, children);
}
export default NextAppDirEmotionCacheProvider;
